pocompile — Translate Toolkit 1.13.0-rc1 documentation

# pocompile

Compile PO or XLIFF files into MO (Machine Object) files. MO files are installed on your computer and allow a Gettext enabled computer to provide the translations for the application.

## Usage

    pocompile <po> <mo>

Where:

<po/xliff> | is a standard PO file, XLIFF file or directory
<mo> | is the output MO file or directory of MO files

Options:

`--version` | show program’s version number and exit
`-h, --help` | show this help message and exit
`--manpage` | output a manpage based on the help
`--progress=PROGRESS`
| show progress as: dots, none, bar, names, verbose
`--errorlevel=ERRORLEVEL`
| show errorlevel as: none, message, exception, traceback
`-iINPUT, --input=INPUT`
| read from INPUT in xlf, po, pot formats
`-xEXCLUDE, --exclude=EXCLUDE`
| exclude names matching EXCLUDE from input paths
`-oOUTPUT, --output=OUTPUT`
| write to OUTPUT in mo format
`--fuzzy` | use translations marked fuzzy
`--nofuzzy` | don’t use translations marked fuzzy (default)

## Examples

    pocompile --fuzzy file.po file.mo

Creates a new MO file called file.mo based on the translation in the PO file file.po. By using the `--fuzzy` option we use all translations including those marked fuzzy.

    pocompile file.xlf file.mo

Create an MO file from an XLIFF file called file.xlf (available from version 1.1 of the toolkit).